@@ -4,7 +4,7 @@ from typing import Annotated
 import typer
 from huggingface_hub import InferenceClient
 from rich import print
-from code_pilot_cli import CHAT_LLM, SYSTEM_MESSAGE, print_highlighted
+from code_star_cli import CHAT_LLM, SYSTEM_MESSAGE, print_highlighted
 
 
 def scan(
@@ -18,6 +18,11 @@ def scan(
 
     Args:
         code (typer.FileText): The file containing code to be scanned.
+
+    Examples:
+    ```shell
+    code-star scan code.py
+    ```
     """
 
     client = InferenceClient(CHAT_LLM)
